# mixer.py
An unofficial Mixer API wrapper written in Python.

### Disclaimer
As of August 2019, this project is still heavily under development and shouldn't be used as anything more than a reference until further notice.
